.. GEOUNED documentation master file, created by
   sphinx-quickstart on Tue Apr 30 09:47:11 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Geouned Documentation
=====================

**Version**: |version|

GEOUNED converts CAD to Constructive Solid Geometry (CSG) formats for use in
Monte Carlo transport codes.
Supported codes include OpenMC, PHITS, Serpent and MCNP.

.. toctree::
   :maxdepth: 3

   install/index
   usage/index
   python_api
   methodology
   developer_guide
